function[A_avg_dup] = avg_dup(A)
% Mitchell Olson (molson@ucdavis.edu)
% Feb 6, 2012
%
% This function finds duplicate values in matrix along the first column,
% averages the values in the remaining columns. It will return a sort
% matrix with duplicate values averaged
%
% Example: Given the matrix 
% A =[ 1     1;
%         1     3;
%         1     5;
%         2     6;
%         3     4;
%         3    11;
%         5     2;
%         8     2;
%         9     7;
%        11    10];
% will return a matrix without duplicate averaged, and removed:
% A_avg_dup = [ 1.00          3.7333;
%                        2.00          6.00;
%                        3.00          7.50;
%                        5.00          2.00;
%                        8.00          2.00;
%                        9.00          7.00;
%                       11.00         10.00];
% 
[u] = unique(A(:,1));
A = sortrows(A,1);
r = histc(A(:,1),u);
 for i = 1:length(u)
     if r(i) ~= 1
            A(i,2:end) = mean(A(i:i+r(i)-1,2:end));
            A(i+1:i+r(i)-1,:) = [];
     end
 end
A_avg_dup = A;
end
